=== modified file 'ChangeLog'
--- ChangeLog	2006-08-20 13:02:35 +0000
+++ ChangeLog	2006-08-20 14:01:33 +0000
@@ -1,5 +1,9 @@
 2006-08-20  Szilveszter Farkas <Szilveszter.Farkas@gmail.com>
 
+    * olive/frontend/gtk/__init__.py: proper handling of permission denied cases
+    * olive/backend/info.py: handle permission denied exception in is_branch()
+    * olive/backend/fileops.py: handle permission denied exception in status()
+    * olive/backend/errors.py: added PermissionDenied exception
     * po/hu.po: added Hungarian traslation
     * Added gettext support to all files.
     * genpot.sh: added olive-gtk.pot generator script

=== modified file 'TODO'
--- TODO	2006-08-19 23:56:40 +0000
+++ TODO	2006-08-20 14:01:33 +0000
@@ -17,6 +17,6 @@
  - Implement 'bzr uncommit' (phanatic)
  - Implement bundle handling - at least creating them (phanatic)
 [DONE] Testing on Windows platform (phanatic)
- - i18n/l10n with gettext (phanatic)
+[DONE] i18n/l10n with gettext (phanatic)
  - Bookmarks should have a 'title' attribute (phanatic)
 [PART-DONE] Open files on double-click, and add Open option to context menu (Aaadam)

=== modified file 'olive/backend/errors.py'
--- olive/backend/errors.py	2006-08-09 14:08:12 +0000
+++ olive/backend/errors.py	2006-08-20 14:01:33 +0000
@@ -187,6 +187,13 @@
         commit.push()
     """
 
+class PermissionDenied(OliveError):
+    """ Permission denied.
+    
+    May occur in:
+        fileops.status()
+    """
+
 class PrefixFormatError(OliveError):
     """ Occurs if the prefix is badly formatted
     

=== modified file 'olive/backend/fileops.py'
--- olive/backend/fileops.py	2006-08-09 14:08:12 +0000
+++ olive/backend/fileops.py	2006-08-20 14:01:33 +0000
@@ -23,7 +23,7 @@
 from errors import (DirectoryAlreadyExists, MissingArgumentError,
                     MultipleMoveError, NoFilesSpecified, NoMatchingFiles,
                     NonExistingSource, NotBranchError, NotSameBranchError,
-                    NotVersionedError)
+                    NotVersionedError, PermissionDenied)
 
 def add(file_list, recursive=False):
     """ Add listed files to the branch. 
@@ -160,6 +160,8 @@
         tree1 = WorkingTree.open_containing(filename)[0]
     except errors.NotBranchError:
         return 'unknown'
+    except errors.PermissionDenied:
+        raise PermissionDenied(filename)
     
     branch = tree1.branch
     tree2 = tree1.branch.repository.revision_tree(branch.last_revision())

=== modified file 'olive/backend/info.py'
--- olive/backend/info.py	2006-08-19 22:59:05 +0000
+++ olive/backend/info.py	2006-08-20 14:01:33 +0000
@@ -22,8 +22,8 @@
 from bzrlib.branch import Branch
 from bzrlib.workingtree import WorkingTree
 
-from errors import (DifferentBranchesError, NotBranchError, PrefixFormatError,
-                    RevisionValueError)
+from errors import (DifferentBranchesError, NotBranchError, PermissionDenied,
+                    PrefixFormatError, RevisionValueError)
 
 def diff(revision=None, file_list=None, diff_options=None, prefix=None):
     """ Save the diff into a temporary file.
@@ -257,6 +257,8 @@
         branch = Branch.open_containing(location)[0]
     except errors.NotBranchError:
         return False
+    except errors.PermissionDenied:
+        raise PermissionDenied(location)
     else:
         return True
         

=== modified file 'olive/frontend/gtk/__init__.py'
--- olive/frontend/gtk/__init__.py	2006-08-20 13:02:35 +0000
+++ olive/frontend/gtk/__init__.py	2006-08-20 14:01:33 +0000
@@ -33,6 +33,7 @@
 
 from handler import OliveHandler
 from olive.backend.info import is_branch
+import olive.backend.errors as errors
 
 # Olive GTK UI version
 __version__ = '0.1'
@@ -191,7 +192,11 @@
         for item in dirs:    
             liststore.append([gtk.STOCK_DIRECTORY, item, ''])
         for item in files:
-            status = fileops.status(path + '/' + item)
+            try:
+                status = fileops.status(path + '/' + item)
+            except errors.PermissionDenied:
+                continue
+            
             if status == 'renamed':
                 st = _('renamed')
             elif status == 'removed':
@@ -224,32 +229,39 @@
         tvcolumn_status.add_attribute(cell, 'text', 2)
         
         # Check if current directory is a branch
-        if is_branch(self.comm.get_path()):
-            self.comm.menuitem_branch.set_sensitive(True)
-            self.comm.menuitem_stats.set_sensitive(True)
-            self.comm.menuitem_add_files.set_sensitive(True)
-            self.comm.menuitem_remove_files.set_sensitive(True)
-            self.comm.menuitem_file_make_directory.set_sensitive(True)
-            self.comm.menuitem_file_rename.set_sensitive(True)
-            self.comm.menuitem_file_move.set_sensitive(True)
-            self.comm.menutoolbutton_diff.set_sensitive(True)
-            self.comm.toolbutton_log.set_sensitive(True)
-            self.comm.toolbutton_commit.set_sensitive(True)
-            self.comm.toolbutton_pull.set_sensitive(True)
-            self.comm.toolbutton_push.set_sensitive(True)
+        try:
+            br = is_branch(self.comm.get_path())
+        except errors.PermissionDenied:
+            pass
         else:
-            self.comm.menuitem_branch.set_sensitive(False)
-            self.comm.menuitem_stats.set_sensitive(False)
-            self.comm.menuitem_add_files.set_sensitive(False)
-            self.comm.menuitem_remove_files.set_sensitive(False)
-            self.comm.menuitem_file_make_directory.set_sensitive(False)
-            self.comm.menuitem_file_rename.set_sensitive(False)
-            self.comm.menuitem_file_move.set_sensitive(False)
-            self.comm.menutoolbutton_diff.set_sensitive(False)
-            self.comm.toolbutton_log.set_sensitive(False)
-            self.comm.toolbutton_commit.set_sensitive(False)
-            self.comm.toolbutton_pull.set_sensitive(False)
-            self.comm.toolbutton_push.set_sensitive(False)
+            if br:
+                # Activate some items
+                self.comm.menuitem_branch.set_sensitive(True)
+                self.comm.menuitem_stats.set_sensitive(True)
+                self.comm.menuitem_add_files.set_sensitive(True)
+                self.comm.menuitem_remove_files.set_sensitive(True)
+                self.comm.menuitem_file_make_directory.set_sensitive(True)
+                self.comm.menuitem_file_rename.set_sensitive(True)
+                self.comm.menuitem_file_move.set_sensitive(True)
+                self.comm.menutoolbutton_diff.set_sensitive(True)
+                self.comm.toolbutton_log.set_sensitive(True)
+                self.comm.toolbutton_commit.set_sensitive(True)
+                self.comm.toolbutton_pull.set_sensitive(True)
+                self.comm.toolbutton_push.set_sensitive(True)
+            else:
+                # Deactivate some items
+                self.comm.menuitem_branch.set_sensitive(False)
+                self.comm.menuitem_stats.set_sensitive(False)
+                self.comm.menuitem_add_files.set_sensitive(False)
+                self.comm.menuitem_remove_files.set_sensitive(False)
+                self.comm.menuitem_file_make_directory.set_sensitive(False)
+                self.comm.menuitem_file_rename.set_sensitive(False)
+                self.comm.menuitem_file_move.set_sensitive(False)
+                self.comm.menutoolbutton_diff.set_sensitive(False)
+                self.comm.toolbutton_log.set_sensitive(False)
+                self.comm.toolbutton_commit.set_sensitive(False)
+                self.comm.toolbutton_pull.set_sensitive(False)
+                self.comm.toolbutton_push.set_sensitive(False)
         
         # set cursor to default
         self.comm.set_busy(self.treeview_right, False)
@@ -395,7 +407,11 @@
         for item in dirs:    
             liststore.append([gtk.STOCK_DIRECTORY, item, ''])
         for item in files:
-            status = fileops.status(path + '/' + item)
+            try:
+                status = fileops.status(path + '/' + item)
+            except errors.PermissionDenied:
+                continue
+            
             if status == 'renamed':
                 st = _('renamed')
             elif status == 'removed':
@@ -414,34 +430,39 @@
         self.treeview_right.set_model(liststore)
         
         # Check if current directory is a branch
-        if is_branch(self.get_path()):
-            # Activate some items
-            self.menuitem_branch.set_sensitive(True)
-            self.menuitem_stats.set_sensitive(True)
-            self.menuitem_add_files.set_sensitive(True)
-            self.menuitem_remove_files.set_sensitive(True)
-            self.menuitem_file_make_directory.set_sensitive(True)
-            self.menuitem_file_rename.set_sensitive(True)
-            self.menuitem_file_move.set_sensitive(True)
-            self.menutoolbutton_diff.set_sensitive(True)
-            self.toolbutton_log.set_sensitive(True)
-            self.toolbutton_commit.set_sensitive(True)
-            self.toolbutton_pull.set_sensitive(True)
-            self.toolbutton_push.set_sensitive(True)
+        try:
+            br = is_branch(self.get_path())
+        except errors.PermissionDenied:
+            pass
         else:
-            # Deactivate some items
-            self.menuitem_branch.set_sensitive(False)
-            self.menuitem_stats.set_sensitive(False)
-            self.menuitem_add_files.set_sensitive(False)
-            self.menuitem_remove_files.set_sensitive(False)
-            self.menuitem_file_make_directory.set_sensitive(False)
-            self.menuitem_file_rename.set_sensitive(False)
-            self.menuitem_file_move.set_sensitive(False)
-            self.menutoolbutton_diff.set_sensitive(False)
-            self.toolbutton_log.set_sensitive(False)
-            self.toolbutton_commit.set_sensitive(False)
-            self.toolbutton_pull.set_sensitive(False)
-            self.toolbutton_push.set_sensitive(False)
+            if br:
+                # Activate some items
+                self.menuitem_branch.set_sensitive(True)
+                self.menuitem_stats.set_sensitive(True)
+                self.menuitem_add_files.set_sensitive(True)
+                self.menuitem_remove_files.set_sensitive(True)
+                self.menuitem_file_make_directory.set_sensitive(True)
+                self.menuitem_file_rename.set_sensitive(True)
+                self.menuitem_file_move.set_sensitive(True)
+                self.menutoolbutton_diff.set_sensitive(True)
+                self.toolbutton_log.set_sensitive(True)
+                self.toolbutton_commit.set_sensitive(True)
+                self.toolbutton_pull.set_sensitive(True)
+                self.toolbutton_push.set_sensitive(True)
+            else:
+                # Deactivate some items
+                self.menuitem_branch.set_sensitive(False)
+                self.menuitem_stats.set_sensitive(False)
+                self.menuitem_add_files.set_sensitive(False)
+                self.menuitem_remove_files.set_sensitive(False)
+                self.menuitem_file_make_directory.set_sensitive(False)
+                self.menuitem_file_rename.set_sensitive(False)
+                self.menuitem_file_move.set_sensitive(False)
+                self.menutoolbutton_diff.set_sensitive(False)
+                self.toolbutton_log.set_sensitive(False)
+                self.toolbutton_commit.set_sensitive(False)
+                self.toolbutton_pull.set_sensitive(False)
+                self.toolbutton_push.set_sensitive(False)
         
         self.set_busy(self.treeview_right, False)
 

